# EvCustomFields

## Migration

Since `2.0.11.1` Without the `tab` database column the `CustomData` tabs won't work correctly.

`cake Migrations.migration run up --plugin=EvCustomFields`

## Disabling and Format

The ability to turn off custom field data has been added into the behaviour.

Any model that "actsAs" CustomFieldsData will have the functionality enabled, when performing a readForEdit / readForView or a standard find. Pass in `customFields` in the parameter array and set it to `false`

This will prevent any custom field information being brought out. Useful for listing type pages where the custom field information is generally not needed.

	$this->MyModel->find(
		'all',
		array(
			'conditions' => array(
				'MyModel.foo' => 'bar'
			),
			'customFields' => false
		)
	);

	$this->MyModel->readForView(
		1,
		array(
			'customFields' => false
		)
	);

In addition, the ability to change the format the data is retrieve in has been added. If you are using the CustomFields helper to retrieve data within the views then this has no effect on that as that helper will check for the different data formats before returning data.

If you are using it to retrieve custom field data via the Hash Path syntax, e.g. for EvCheckout, then you will need to make sure the following option is enabled within the find / readForView / readForEdit; `customFieldsSyntaxFormat`.

As default, `readForView` is set so the data will be retrieved with this syntaxFormat option turned on, `readForEdit` will return custom field data in the original format.

Default Format:

	'CustomFieldData' => array(
		(int) 1 => array(
			'FieldData' => array(
				'id' => '7',
				'field_id' => '1',
				'value' => '<p>features123123</p>',
				'model' => 'EvShop.Product',
				'model_id' => '3',
				'created' => '2015-09-23 14:39:38',
				'modified' => '2015-09-23 14:39:38'
			),
			'Field' => array(
				'id' => '1',
				'name' => 'features',
				'label' => 'Product Features',
				'type' => 'html',
				'options' => '',
				'validation' => '',
				'model' => 'EvTemplates.Template',
				'model_id' => '6',
				'sequence' => '0',
				'is_active' => true,
				'created' => '2015-07-30 15:05:24',
				'modified' => '2015-07-30 15:10:17'
			)
		),
		(int) 2 => array(
			'FieldData' => array(
				'id' => '8',
				'field_id' => '2',
				'value' => '<p>spec456456</p>',
				'model' => 'EvShop.Product',
				'model_id' => '3',
				'created' => '2015-09-23 14:39:38',
				'modified' => '2015-09-23 14:39:38'
			),
			'Field' => array(
				'id' => '2',
				'name' => 'specification',
				'label' => 'Specification',
				'type' => 'html',
				'options' => '',
				'validation' => '',
				'model' => 'EvTemplates.Template',
				'model_id' => '6',
				'sequence' => '1',
				'is_active' => true,
				'created' => '2015-07-30 15:05:24',
				'modified' => '2015-07-30 15:10:17'
			)
		),
		(int) 3 => array(
			'FieldData' => array(
				'id' => '9',
				'field_id' => '3',
				'value' => '<p>delivery5675678</p>',
				'model' => 'EvShop.Product',
				'model_id' => '3',
				'created' => '2015-09-23 14:39:38',
				'modified' => '2015-09-23 14:39:38'
			),
			'Field' => array(
				'id' => '3',
				'name' => 'delivery',
				'label' => 'Delivery',
				'type' => 'html',
				'options' => '',
				'validation' => '',
				'model' => 'EvTemplates.Template',
				'model_id' => '6',
				'sequence' => '2',
				'is_active' => true,
				'created' => '2015-07-30 15:05:24',
				'modified' => '2015-07-30 15:10:17'
			)
		)
	),

Syntax Format:

	'CustomFieldData' => array(
		'features' => '<p>features123123</p>',
		'specification' => '<p>spec456456</p>',
		'delivery' => '<p>delivery5675678</p>'
	)

This allows for Hash Paths to be used to retrieve Custom Field Data more easily, should it be needed for configs. e.g. `Hash::extract($results, '{n}.CustomFieldData.features');`

